pub struct ChatCompletionRequestFunctionCall {
pub model: String,
pub messages: Vec<ChatFnMessages>,
pub temperature: Option<f64>,
pub top_p: Option<f64>,
pub max_tokens: Option<u32>,
pub stream: Option<bool>,
pub safe_prompt: Option<bool>,
pub tools: Option<Vec<ChatCompletionRequestFunctionCallToolsInner>>,
pub tool_choice: Option<String>,
pub random_seed: Option<i32>,
}Fields
model: StringID of the model to use. You can use the List Available Models API to see all of your available models, or see our Model overview for model descriptions.
messages: Vec<ChatFnMessages>The prompt(s) to generate completions for, encoded as a list of dict with role and content. The first prompt role should be user or system. When role is tool, the properties should contain tool_call_id (string or null).
temperature: Option<f64>What sampling temperature to use, between 0.0 and 1.0. Higher values like 0.8 will make the output more random, while lower values like 0.2 will make it more focused and deterministic. We generally recommend altering this or top_p but not both.
top_p: Option<f64>Nucleus sampling, where the model considers the results of the tokens with top_p probability mass. So 0.1 means only the tokens comprising the top 10% probability mass are considered. We generally recommend altering this or temperature but not both.
max_tokens: Option<u32>The maximum number of tokens to generate in the completion. The token count of your prompt plus max_tokens cannot exceed the model’s context length.
stream: Option<bool>Whether to stream back partial progress. If set, tokens will be sent as data-only server-sent events as they become available, with the stream terminated by a data: [DONE] message. Otherwise, the server will hold the request open until the timeout or until completion, with the response containing the full result as JSON.
safe_prompt: Option<bool>Whether to inject a safety prompt before all conversations.
tools: Option<Vec<ChatCompletionRequestFunctionCallToolsInner>>A list of available tools for the model. Use this to specify functions for which the model can generate JSON inputs.
tool_choice: Option<String>Specifies if/how functions are called. If set to none the model won’t call a function and will generate a message instead. If set to auto the model can choose to either generate a message or call a function. If set to any the model is forced to call a function.
random_seed: Option<i32>The seed to use for random sampling. If set, different calls will generate deterministic results.
Implementations
Sourceimpl ChatCompletionRequestFunctionCall
impl ChatCompletionRequestFunctionCall
Sourcepub fn new(
model: String,
messages: Vec<ChatFnMessages>,
) -> ChatCompletionRequestFunctionCall
pub fn new( model: String, messages: Vec<ChatFnMessages>, ) -> ChatCompletionRequestFunctionCall